@@ -528,7 +528,7 @@ get_score_matrix_feglm_ <- function(object) {
     attr(x, "dimnames") <- NULL
 
     # Center variables
-    x <- center_variables_r_(x, w, k_list, control[["center_tol"]], control[["iter_max"]], control[["interrupt_iter"]])
+    x <- center_variables_r_(x, w, k_list, control[["center_tol"]], control[["iter_max"]], control[["interrupt_iter"]], control[["iter_ssr"]])
     colnames(x) <- nms_sp
   }
 
