@@ -11,7 +11,7 @@ using namespace cpp11;
 
 void center_variables_(mat &V, const vec &w, const list &klist,
                        const double &tol, const int &max_iter,
-                       const int &iter_interrupt);
+                       const int &iter_interrupt, const int &iter_ssr);
 
 vec solve_beta_(mat MX, const mat &MNU, const vec &w);
 
